@@ -4,6 +4,7 @@ from renderers import templates
 from formalchemy import config
 from utils import TemplateEngine
 from forms import Tabs, Accordion
+import simplejson
 from testing import *
 
 config.engine = TemplateEngine()
@@ -18,7 +19,8 @@ class Demo(object):
         req = Request(environ)
         if req.path.endswith('/fa.jquery/ajax_values'):
             resp = Response()
-            resp.body = '\n'.join(['Ajax','Borax','Corax', 'Dorax','Manix'])
+            resp.content_type='application/json'
+            resp.body = simplejson.dumps([{'value':'Ajax'},{'value':'Borax'},{'value':'Corax'}, {'value':'Dorax'},{'value':'Manix'}])
         elif req.path.endswith('/fa.jquery/demo.html'):
             script_name = req.environ.get('HTTP_X_FORWARDED_PATH', '')
             Form.ajax.set(renderer=AutoCompleteFieldRenderer(script_name+'/fa.jquery/ajax_values'))
@@ -26,20 +28,20 @@ class Demo(object):
             obj.context['slider'] = '10'
             obj.context['sortable'] = '1;2;3'
             obj.context['selectable'] = 'f'
-            obj.context['selectable_token'] = 'b;c'
+            obj.context['selectables'] = ['b', 'c']
             fs = Form.bind(obj, data=req.POST or None)
 
             tabs = Tabs('my_tabs',
                         ('tab1', 'My first tab', fs1),
                         ('tab2', 'The second', fs2),
                         footer='<input type="submit" name="%(id)s" />')
-            tabs.bind(obj1, 'tab1', data=req.POST or None)
-            tabs.bind(obj2, 'tab2', data=req.POST or None)
+            tabs.bind(fs1.gen_model(), 'tab1', data=req.POST or None)
+            tabs.bind(fs2.gen_model(), 'tab2', data=req.POST or None)
             accordion = Accordion('my_accordion',
                         ('tab1', 'My first section', fs3),
                         ('tab2', 'The second', fs4),
                         footer='<input type="submit" name="%(id)s" />')
-            accordion.bind(obj3, data=req.POST or None)
+            accordion.bind(fs3.gen_model(), data=req.POST or None)
             if req.POST:
                 if fs.validate():
                     fs.sync()
