@@ -30,9 +30,10 @@ class ISample(interface.Interface):
     title = schema.TextLine(title=u'Autocomplete')
     ajax = schema.TextLine(title=u'Auto complete with an ajax request')
     color = schema.TextLine(title=u'Color picker')
+    rich = schema.Text(title=u'TinyMCE')
+    markdown = schema.Text(title=u'Markdown editor using Markitup!. Textile and bbcode format are also supported')
     selectable = schema.TextLine(title=u'Selectable')
-    selectable_token = schema.TextLine(title=u'Selectable token',
-                              description=u'Save values as a string separate by a semi comma')
+    selectables = schema.List(title=u'Selectables')
     sortable = schema.TextLine(title=u'Sortable token',
                               description=u'Save values as a string separate by a semi comma')
     slider = schema.Int(title=u'Integer as slider')
@@ -43,11 +44,13 @@ class ISample(interface.Interface):
 Form = FieldSet(ISample)
 Form.title.set(renderer=AutoCompleteFieldRenderer(['aa', 'bb']))
 Form.ajax.set(renderer=AutoCompleteFieldRenderer('/fa.jquery/ajax_values'))
+Form.rich.set(renderer=tinymce())
+Form.markdown.set(renderer=markdown())
 Form.color.set(renderer=ColorPickerFieldRenderer())
 Form.slider.set(renderer=SliderFieldRenderer)
-Form.selectable.set(renderer=SelectableFieldRenderer, options=[l for l in 'abcdef'])
-Form.selectable_token.set(renderer=SelectableTokenFieldRenderer, options=[l for l in 'abcdef'])
-Form.sortable.set(renderer=SortableTokenTextFieldRenderer)
+Form.selectable.set(renderer=selectable(), options=[l for l in 'abcdef'])
+Form.selectables.set(renderer=selectables(), options=[l for l in 'abcdef'])
+Form.sortable.set(renderer=SortableTokenTextFieldRenderer())
 Form.resources.set(renderer=jQueryFieldRenderer('test_resources',
                                                 resources=['/jquery/fa.resource.js','/jquery/fa.resource.css']))
 
